@@ -1,11 +1,11 @@
 package Weed::ArrayField;
 use Weed;
 
-our $VERSION = '0.0078';
+our $VERSION = '0.0079';
 
-sub setDescription {
+sub SET_DESCRIPTION {
 	my ( $this, $description ) = @_;
-	$this->X3DField::setDescription($description);
+	$this->X3DField::SET_DESCRIPTION($description);
 	$_[0]->X3DPackage::Scalar("FieldType") = 'S' . substr $description->{typeName}, 1;
 }
 
@@ -13,8 +13,8 @@ use Weed 'X3DArrayField : X3DField { [] }';
 
 use base 'Weed::Array';
 
-use Weed::Tie::ArrayFieldValue;
-use Weed::Tie::Length;
+use Weed::Tie::Value::Array;
+use Weed::Tie::ArrayLength;
 
 use overload '@{}' => 'getValue';
 
@@ -23,8 +23,8 @@ sub new { shift->X3DField::new(@_) }
 sub new_from_definition {    # also in MFNode
 	my $this = shift->X3DField::new_from_definition(@_);
 
-	tie @{ $this->getValue }, 'Weed::Tie::ArrayFieldValue', $this;
-	tie $this->length, 'Weed::Tie::Length', $this->getValue;
+	tie @{ $this->getValue }, 'Weed::Tie::Value::Array', $this;
+	tie $this->length, 'Weed::Tie::ArrayLength', $this->getValue;
 
 	return $this;
 }
@@ -39,14 +39,36 @@ sub getValue { shift->X3DField::getValue }
 sub setValue {
 	my $this  = shift;
 	my $array = $this->getValue;
-	$array->setValue(@_);
+
+	if ( 0 == @_ ) {
+		@$array = ();
+	}
+	elsif ( 1 == @_ )
+	{
+		my $value = shift;
+
+		if ( X3DArray::isArray($value) ) {
+			@$array = @$value;
+		}
+		else {
+			@$array = ($value);
+		}
+	}
+	else {
+		@$array = @_;
+	}
+
 	$this->X3DField::setValue($array);
 }
 
+
+
 sub set1Value {
+	warn;
 }
 
 sub get1Value {
+	warn;
 }
 
 sub length : lvalue { $_[0]->{length} }
