@@ -1,6 +1,6 @@
 package Weed::ArrayHash;
 
-our $VERSION = '0.002';
+our $VERSION = '0.0003';
 
 use Weed 'X3DArrayHash : X3DArray X3DHash ()';
 
@@ -20,9 +20,9 @@ use overload
 sub new {
 	my $self = $_[0];
 	my $type = ref($self) || $self;
-	my $this = bless \{}, $type;
-	$$this->{array} = new X3DArray $_[1];
-	$$this->{hash}  = new X3DHash $_[2];
+	my $this = bless do { my $scalar; \$scalar }, $type;
+	$$this->{array} = new X3DArray;
+	$$this->{hash}  = new X3DHash;
 	return $this;
 }
 
