@@ -1,7 +1,7 @@
 package Weed::BaseFieldTypes::Vector;
 use Weed::Perl;
 
-our $VERSION = '0.009';
+our $VERSION = '0.0081';
 
 use base 'Weed::BaseFieldTypes::Scalar';
 
@@ -16,11 +16,7 @@ use overload
 
   'neg' => sub { -$_[0]->getValue },
 
-  #'++' => sub { my $value = $_[0]->getValue; ++$value; $_[0] },
-  #'+=' => sub { print "+="; $_[0]->getValue->setValue($_[0]->getValue + $_[1]); $_[0] },
-  #'-=' => sub { print "-="; $_[2] ? $_[1] - $_[0]->getValue : $_[0]->getValue - $_[1] },
-
-  '.' => sub { $_[2] ? $_[1] . $_[0]->getValue : $_[0]->getValue . $_[1] },
+  '.' => sub { $_[0]->getValue . $_[1] },
   'x' => sub { $_[2] ? $_[1] x $_[0]->getValue : $_[0]->getValue x $_[1] },
 
   '@{}' => sub { $_[0]->{array} },
@@ -29,20 +25,17 @@ use overload
 use Weed::Tie::Value::Vector;
 use Weed::FieldHelper;
 
-#*new = \&X3DField::new;
-
 sub new_from_definition {
 	my $this = shift->X3DField::new_from_definition(@_);
-	$this->{array} = new Weed::Tie::Value::Vector $this;
+	$this->{array} = [];
+	tie @{ $this->{array} }, 'Weed::Tie::Value::Vector', $this;
 	return $this;
 }
 
-sub getInitialValue { $_[0]->getDefinition->getValue->getClone }
-
 sub setValue {
 	my $this   = shift;
 	my $vector = $this->getValue;
-	$vector->setValue( @_ ? Weed::FieldHelper::NumVal( scalar @$vector, @_ ) : $this->getDefaultValue );
+	$vector->setValue( @_ ? Weed::FieldHelper::NumVal(scalar @$vector, @_) : $this->getDefaultValue );
 	$this->X3DField::setValue($vector);
 }
 
