@@ -1,16 +1,18 @@
 package Weed::FieldTypes::SFString;
 
-our $VERSION = '0.0078';
+our $VERSION = '0.0079';
 
 use Weed 'SFString : X3DField { "" }';
 
+use base 'Weed::BaseFieldTypes::Scalar';
+
 use Unicode::String;
 #Text::Unidecode;
-
 use overload
-  'int' => sub { length $_[0]->getValue },
-  '0+'  => sub { length $_[0]->getValue },
-  ;
+#  '0+' => 'length',
+  '~' => sub { ~$_[0]->getValue },
+ ;
+
 
 sub setValue {
 	my ( $this, $value ) = @_;
