@@ -1,27 +1,26 @@
 package Weed::Tie::Value::Array;
 use Weed;
 
-our $VERSION = '0.011';
+our $VERSION = '0.008';
 
 use base 'Tie::Array';
 
+#use Contextual::Return;
 use Scalar::Util 'weaken';
 
-sub new {
-	tie my (@array), $_[0], $_[1];
-	return \@array;
-}
-
-sub getValue  { $_[0]->{parent}->getValue }
+sub getValue  { $_[0]->{value} }
 sub getParent { $_[0]->{parent} }
 
 sub storeValue {
-	return $_[0]->{fieldType}->new( $_[1] )->getValue;
+	$_[0]->{fieldType}->new( $_[1] )->getValue;
 }
 
 sub fetchValue {
 	my ( $this, $value ) = @_;
-	return $this->{fieldType}->new($value)->getValue;
+
+	$this->{fieldType}->new(
+		defined $value ? $value : $this->{fieldType}->getDefaultValue
+	);
 }
 
 sub insertValues {
@@ -36,6 +35,7 @@ sub removeValues {
 
 sub TIEARRAY {
 	my $this = bless {
+		value     => [ @{ $_[1]->getValue } ], # weg machen tie tie in array oben in arrayfield
 		parent    => $_[1],
 		fieldType => $_[1]->getFieldType,
 	  },
@@ -46,51 +46,26 @@ sub TIEARRAY {
 	return $this;
 }
 
-sub STORE {
-	$_[0]->getValue->[ $_[1] ] = $_[0]->storeValue( $_[2] );
-}
+sub STORE { $_[0]->{value}->[ $_[1] ] = $_[0]->storeValue( $_[2] ) }
 
 sub FETCH {
-	#return $_[0]->getValue->[ $_[1] ] if want('REF');
+	#print 'ARRAY' if Want::want('ARRAY');
+	return if $_[1] > $#{ $_[0]->{value} };
 
-	return $_[0]->fetchValue( $_[0]->getValue->[ $_[1] ] )
-	  if $_[1] < @{ $_[0]->getValue };
-
-	return;
+	$_[0]->fetchValue( $_[0]->{value}->[ $_[1] ] );
 }
 
-sub FETCHSIZE { scalar @{ $_[0]->getValue } }
-sub EXISTS    { exists $_[0]->getValue->[ $_[1] ] }
+sub FETCHSIZE { scalar @{ $_[0]->{value} } }
+sub EXISTS    { exists $_[0]->{value}->[ $_[1] ] }
 
-sub STORESIZE {
-	$#{ $_[0]->getValue } = $_[1] - 1;
-}
+sub STORESIZE { $#{ $_[0]->{value} } = $_[1] - 1 }
+sub CLEAR { @{ $_[0]->{value} } = () }
+sub DELETE { delete $_[0]->{value}->[ $_[1] ] }
 
-sub CLEAR {
-	@{ $_[0]->getValue } = ();
-}
-
-sub DELETE {
-	delete $_[0]->getValue->[ $_[1] ];
-}
-
-sub POP {
-	$_[0]->removeValues( pop( @{ $_[0]->getValue } ) );
-}
-
-sub PUSH {
-	my $this = shift;
-	my $o    = $this->getValue;
-	push @$o, $this->insertValues(@_);
-}
-
-sub SHIFT { $_[0]->removeValues( shift( @{ $_[0]->getValue } ) ) }
-
-sub UNSHIFT {
-	my $this = shift;
-	my $o    = $this->getValue;
-	return unshift @$o, $this->insertValues(@_);
-}
+sub POP     { $_[0]->removeValues( pop( @{ $_[0]->{value} } ) ) }
+sub PUSH    { my $this = shift; my $o = $this->{value}; push( @$o, $this->insertValues(@_) ) }
+sub SHIFT   { $_[0]->removeValues( shift( @{ $_[0]->{value} } ) ) }
+sub UNSHIFT { my $this = shift; my $o = $this->{value}; unshift( @$o, $this->insertValues(@_) ) }
 
 sub SPLICE {
 	my $this = shift;
@@ -98,7 +73,7 @@ sub SPLICE {
 	my $off  = @_ ? shift : 0;
 	$off += $sz if $off < 0;
 	my $len = @_ ? shift : $sz - $off;
-	return $this->removeValues( splice( @{ $this->getValue }, $off, $len, @_ ) );
+	return $this->removeValues( splice( @{ $this->{value} }, $off, $len, @_ ) );
 }
 
 sub UNTIE { $_[0]->CLEAR }
