@@ -1,13 +1,12 @@
 package Weed::Tie::Value::BaseNodeArray;
 use Weed;
 
-our $VERSION = '0.009';
+our $VERSION = '0.0079';
 
 use base 'Weed::Tie::Value::Array';
 
 sub storeValue {
 	my ( $this, $value ) = @_;
-
 	my $node = $this->{fieldType}->new($value)->getValue;
 
 	if ($node) {
@@ -18,6 +17,7 @@ sub storeValue {
 			$this->{nodes}->{$id} = 1;
 			$node->getParents->add( $this->getParent );
 		}
+		$node->addClone;
 	}
 
 	return $node;
@@ -37,6 +37,8 @@ sub removeParents {
 		unless ( --$this->{nodes}->{$id} ) {
 			delete $this->{nodes}->{$id};
 			$node->getParents->remove( $this->getParent );
+			$node->removeClone;
+			$node->dispose;
 		}
 	}
 }
