@@ -1,38 +1,41 @@
 package Weed::Values::ColorRGBA;
 use Weed::Perl;
 
-our $VERSION = '0.0078';
+our $VERSION = '0.0079';
+
+use Package::Alias X3DColorRGBA => __PACKAGE__;
 
 use Weed::Values::Color;
+use Weed::Values::Vec4;
 
-use base 'Weed::Values::Vec4';
+use base 'X3DVec4';
 
 use constant getDefaultValue => [ 0, 0, 0, 0 ];
 
-*setRed = \&Weed::Values::Vec4::setX;
-*getRed = \&Weed::Values::Vec4::getX;
+*setRed = \&X3DVec4::setX;
+*getRed = \&X3DVec4::getX;
 
-*setGreen = \&Weed::Values::Vec4::setY;
-*getGreen = \&Weed::Values::Vec4::getY;
+*setGreen = \&X3DVec4::setY;
+*getGreen = \&X3DVec4::getY;
 
-*setBlue = \&Weed::Values::Vec4::setZ;
-*getBlue = \&Weed::Values::Vec4::getZ;
+*setBlue = \&X3DVec4::setZ;
+*getBlue = \&X3DVec4::getZ;
 
-*setAlpha = \&Weed::Values::Vec4::setW;
-*getAlpha = \&Weed::Values::Vec4::getW;
+*setAlpha = \&X3DVec4::setW;
+*getAlpha = \&X3DVec4::getW;
 
-*getValue = \&Weed::Values::Color::getValue;
+*getValue = \&X3DColor::getValue;
 
-*setValue = \&Weed::Values::Color::setValue;
+*setValue = \&X3DColor::setValue;
 
 sub setRGB { @{ $_[0] }[ 0, 1, 2 ] = @{ $_[1] }[ 0, 1, 2 ] }
 
-sub getRGB { new Weed::Values::Color( map { Math::clamp( $_, 0, 1 ) } @{ $_[0] }[ 0, 1, 2 ] ) }
+sub getRGB { new X3DColor [ map { X3DMath::clamp( $_, 0, 1 ) } @{ $_[0] }[ 0, 1, 2 ] ] }
 
 sub setHSV {
 	my ( $this, $h, $s, $v, $a ) = @_;
 
-	my $c = new Weed::Values::Color;
+	my $c = new X3DColor;
 	$c->setHSV( $h, $s, $v );
 
 	$this->setRGB($c);
@@ -76,7 +79,7 @@ sub add {
 	  ] );
 }
 
-use overload '+=' => 'Weed::Values::Color::(+=';
+use overload '+=' => 'X3DColor::(+=';
 
 sub subtract {
 	my ( $a, $b, $r ) = @_;
@@ -101,7 +104,7 @@ sub subtract {
 	  ] );
 }
 
-use overload '-=' => 'Weed::Values::Color::(-=';
+use overload '-=' => 'X3DColor::(-=';
 
 sub multiply {
 	my ( $a, $b, $r ) = @_;
@@ -121,7 +124,7 @@ sub multiply {
 	  ] );
 }
 
-use overload '*=' => 'Weed::Values::Color::(*=';
+use overload '*=' => 'X3DColor::(*=';
 
 sub divide {
 	my ( $a, $b, $r ) = @_;
@@ -146,32 +149,32 @@ sub divide {
 	  ] );
 }
 
-use overload '/=' => 'Weed::Values::Color::(/=';
+use overload '/=' => 'X3DColor::(/=';
 
 sub mod {
 	my ( $a, $b, $r ) = @_;
 	return ref $b ?
 	  $a->new( [
 			$r ? (
-				Math::fmod( $b->[0], $a->[0] ),
-				Math::fmod( $b->[1], $a->[1] ),
-				Math::fmod( $b->[2], $a->[2] ),
+				X3DMath::fmod( $b->[0], $a->[0] ),
+				X3DMath::fmod( $b->[1], $a->[1] ),
+				X3DMath::fmod( $b->[2], $a->[2] ),
 				$b->[3],
 			  ) : (
-				Math::fmod( $a->[0], $b->[0] ),
-				Math::fmod( $a->[1], $b->[1] ),
-				Math::fmod( $a->[2], $b->[2] ),
+				X3DMath::fmod( $a->[0], $b->[0] ),
+				X3DMath::fmod( $a->[1], $b->[1] ),
+				X3DMath::fmod( $a->[2], $b->[2] ),
 				$a->[3],
 			  ) ] )
 	  : $a->new( [
-			Math::fmod( $a->[0], $b ),
-			Math::fmod( $a->[1], $b ),
-			Math::fmod( $a->[2], $b ),
+			X3DMath::fmod( $a->[0], $b ),
+			X3DMath::fmod( $a->[1], $b ),
+			X3DMath::fmod( $a->[2], $b ),
 			$a->[3],
 	  ] );
 }
 
-use overload '%=' => 'Weed::Values::Color::(%=';
+use overload '%=' => 'X3DColor::(%=';
 
 sub pow {
 	my ( $a, $b, $r ) = @_;
@@ -190,9 +193,9 @@ sub pow {
 	] );
 }
 
-use overload '**=' => 'Weed::Values::Color::(**=';
+use overload '**=' => 'X3DColor::(**=';
 
-use overload '.' => 'Weed::Values::Vec3::dot';
+use overload '.' => 'X3DVec3::dot';
 
 sub cross {
 	my ( $a, $b, $r ) = @_;
@@ -209,7 +212,7 @@ sub cross {
 	] );
 }
 
-use overload 'x=' => 'Weed::Values::Color::(x=';
+use overload 'x=' => 'X3DColor::(x=';
 
 use overload 'cos' => sub { $_[0]->new( [ ( map { CORE::cos($_) } @{ $_[0] }[ 0, 1, 2 ] ), $_[0]->[3] ] ) };
 use overload 'sin' => sub { $_[0]->new( [ ( map { CORE::sin($_) } @{ $_[0] }[ 0, 1, 2 ] ), $_[0]->[3] ] ) };
